teamhealthcheck

package module
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2020 License: MIT Imports: 0 Imported by: 0

README

go-teamhealthcheck

Build Status

Content

  1. Concept of the Team/Squad Health Check
  2. Goal of this Module
  3. Usage
  4. Contribution
Concept of the Team Health Check

The Team/Squad Health Check was formerly mentioned from Spotify as the Squad Health Check. It is used to evaluate and identify on how is the team doing. The Stakeholders of this Health Check are the teams themselves as also shared Leaders, so that those get a sense on where to focus their improvement efforts, spot systemic problems, and help teams become more self-aware so they can focus their improvement efforts too. further reading

Goal of this Module

The module should help you to provide a simple model of the Health Check to just be able to implement a Service or API to use the Health Check. Mostly because the Teams I'm working with requested to gather the data not manually anymore, but through an App or website, I decided to start simple with a model.

Next Steps

This model just reached version v0.1.0. So it's the very beginning. Once I'm starting to use it more often, this model will get extentend when it makes sense. There will be example implementations following.

Otherwise just check the Changelog.

Usage

As this is a simple model, the usage is concidered the following path:

  // Beginning of your go file / function / ...
  metric1 := teamhealthcheck.New("Metric 1")
  metric1.SetTendency(2)
  metric1.SetRed(2)
  ...
Contribution

Feel free to contribute, but make sure to follow along with the following guideline for Commits:

Structural elements:

  • fix: a commit of the type fix patches a bug in your codebase (this correlates with PATCH in semantic versioning)
  • feat: a commit of the type feat introduces a new feature to the codebase (this correlates with MINOR in semantic versioning).
  • BREAKING CHANGE: a commit that has the text BREAKING CHANGE: at the beginning of its optional body or footer section introduces a breaking API change (correlating with MAJOR in semantic versioning). A BREAKING CHANGE can be part of commits of any type.
  • chore, docs, style, refactor, perf or test are fine too

further reading

Commit messages:

  • Separate subject from body with a blank line
  • Limit the subject line to 50 characters
  • Capitalize the subject line
  • Do not end the subject line with a period
  • Use the imperative mood in the subject line
  • Wrap the body at 72 characters
  • Use the body to explain what and why vs. how

further reading

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type HealthMetric

type HealthMetric struct {
	Indicator
	// contains filtered or unexported fields
}

HealthMetric defines a metric within a Squad Health Check

func New

func New(title string) HealthMetric

New generates a new HealthMetric

func (*HealthMetric) SetTendency

func (h *HealthMetric) SetTendency(tendency int)

SetTendency sets the title of the HealthMetric

func (*HealthMetric) SetTitle

func (h *HealthMetric) SetTitle(title string)

SetTitle sets the title of the HealthMetric

func (*HealthMetric) Tendency

func (h *HealthMetric) Tendency() int

Tendency returns the tendency of the HealthMetric

func (*HealthMetric) Title

func (h *HealthMetric) Title() string

Title returns the title of the HealthMetric

type Indicator

type Indicator struct {
	// contains filtered or unexported fields
}

Indicator defines red, yellow and green as health metric

func (*Indicator) Green

func (i *Indicator) Green() int

Green is Getter for the Indicators indicator green

func (*Indicator) Indicator

func (i *Indicator) Indicator() Indicator

Indicator is Getter for the Indicator

func (*Indicator) Red

func (i *Indicator) Red() int

Red is Getter for the Indicators indicator red

func (*Indicator) SetGreen

func (i *Indicator) SetGreen(green int)

SetGreen is Setter for Green

func (*Indicator) SetRed

func (i *Indicator) SetRed(red int)

SetRed is Setter for Red

func (*Indicator) SetYellow

func (i *Indicator) SetYellow(yellow int)

SetYellow is Setter for Yellow

func (*Indicator) Yellow

func (i *Indicator) Yellow() int

Yellow is Getter for the Indicators indicator yellow

Jump to